@@ -80,47 +80,45 @@ impl<'a> StructInfo<'a> {
                 quote!()
             }
         });
-        let builder_method_doc = match self.builder_attr.builder_method_doc {
-            Some(ref doc) => quote!(#doc),
-            None => {
-                let doc = format!(
-                    "
+        let builder_method_doc = if let Some(ref doc) = self.builder_attr.builder_method_doc {
+            quote!(#doc)
+        } else {
+            let doc = format!(
+                "
                     Create a builder for building `{name}`.
                     On the builder, call {setters} to set the values of the fields.
                     Finally, call `.build()` to create the instance of `{name}`.
                     ",
-                    name = self.name,
-                    setters = {
-                        let mut result = String::new();
-                        let mut is_first = true;
-                        for field in self.included_fields() {
-                            use std::fmt::Write;
-                            if is_first {
-                                is_first = false;
-                            } else {
-                                write!(&mut result, ", ").unwrap();
-                            }
-                            write!(&mut result, "`.{}(...)`", field.name).unwrap();
-                            if field.builder_attr.default.is_some() {
-                                write!(&mut result, "(optional)").unwrap();
-                            }
+                name = self.name,
+                setters = {
+                    let mut result = String::new();
+                    let mut is_first = true;
+                    for field in self.included_fields() {
+                        use std::fmt::Write;
+                        if is_first {
+                            is_first = false;
+                        } else {
+                            write!(&mut result, ", ").unwrap();
+                        }
+                        write!(&mut result, "`.{}(...)`", field.name).unwrap();
+                        if field.builder_attr.default.is_some() {
+                            write!(&mut result, "(optional)").unwrap();
                         }
-                        result
                     }
-                );
-                quote!(#doc)
-            }
+                    result
+                }
+            );
+            quote!(#doc)
         };
         let builder_type_doc = if self.builder_attr.doc {
-            match self.builder_attr.builder_type_doc {
-                Some(ref doc) => quote!(#[doc = #doc]),
-                None => {
-                    let doc = format!(
-                        "Builder for [`{name}`] instances.\n\nSee [`{name}::builder()`] for more info.",
-                        name = name
-                    );
-                    quote!(#[doc = #doc])
-                }
+            if let Some(ref doc) = self.builder_attr.builder_type_doc {
+                quote!(#[doc = #doc])
+            } else {
+                let doc = format!(
+                    "Builder for [`{name}`] instances.\n\nSee [`{name}::builder()`] for more info.",
+                    name = name
+                );
+                quote!(#[doc = #doc])
             }
         } else {
             quote!(#[doc(hidden)])
@@ -168,9 +166,9 @@ impl<'a> StructInfo<'a> {
 
     // TODO: once the proc-macro crate limitation is lifted, make this an util trait of this
     // crate.
-    pub fn conversion_helper_impl(&self) -> Result<TokenStream, Error> {
+    pub fn conversion_helper_impl(&self) -> TokenStream {
         let trait_name = &self.conversion_helper_trait_name;
-        Ok(quote! {
+        quote! {
             #[doc(hidden)]
             #[allow(dead_code, non_camel_case_types, non_snake_case)]
             pub trait #trait_name<T> {
@@ -188,7 +186,7 @@ impl<'a> StructInfo<'a> {
                     self.0
                 }
             }
-        })
+        }
     }
 
     pub fn field_impl(&self, field: &FieldInfo) -> Result<TokenStream, Error> {
@@ -206,7 +204,7 @@ impl<'a> StructInfo<'a> {
 
         let &FieldInfo {
             name: ref field_name,
-            ty: ref field_type,
+            ty: field_type,
             ..
         } = field;
         let mut ty_generics: Vec<syn::GenericArgument> = self
@@ -333,7 +331,7 @@ impl<'a> StructInfo<'a> {
         })
     }
 
-    pub fn required_field_impl(&self, field: &FieldInfo) -> Result<TokenStream, Error> {
+    pub fn required_field_impl(&self, field: &FieldInfo) -> TokenStream {
         let StructInfo {
             ref name,
             ref builder_name,
@@ -416,7 +414,7 @@ impl<'a> StructInfo<'a> {
         );
         let early_build_error_message = format!("Missing required field {}", field_name);
 
-        Ok(quote! {
+        quote! {
             #[doc(hidden)]
             #[allow(dead_code, non_camel_case_types, non_snake_case)]
             pub enum #early_build_error_type_name {}
@@ -430,7 +428,7 @@ impl<'a> StructInfo<'a> {
                     panic!();
                 }
             }
-        })
+        }
     }
 
     pub fn build_method_impl(&self) -> TokenStream {
@@ -511,24 +509,38 @@ impl<'a> StructInfo<'a> {
         });
         let field_names = self.fields.iter().map(|field| field.name);
         let doc = if self.builder_attr.doc {
-            match self.builder_attr.build_method_doc {
-                Some(ref doc) => quote!(#[doc = #doc]),
-                None => {
-                    // I'd prefer “a” or “an” to “its”, but determining which is grammatically
-                    // correct is roughly impossible.
-                    let doc = format!("Finalise the builder and create its [`{}`] instance", name);
-                    quote!(#[doc = #doc])
-                }
+            if let Some(ref doc) = self.builder_attr.build_method_doc {
+                quote!(#[doc = #doc])
+            } else {
+                // I'd prefer “a” or “an” to “its”, but determining which is grammatically
+                // correct is roughly impossible.
+                let doc = format!("Finalise the builder and create its [`{}`] instance", name);
+                quote!(#[doc = #doc])
             }
         } else {
             quote!()
         };
+
+        let build_method_name = self
+            .builder_attr
+            .build_method
+            .name
+            .as_ref()
+            .map(|name| quote!(#name))
+            .unwrap_or(quote!(build));
+        let visibility = self
+            .builder_attr
+            .build_method
+            .vis
+            .as_ref()
+            .map(|v| quote!(#v))
+            .unwrap_or(quote!(pub));
         quote!(
             #[allow(dead_code, non_camel_case_types, missing_docs)]
             impl #impl_generics #builder_name #modified_ty_generics #where_clause {
                 #doc
                 #[allow(clippy::default_trait_access)]
-                pub fn build(self) -> #name #ty_generics {
+                #visibility fn #build_method_name(self) -> #name #ty_generics {
                     let ( #(#descructuring,)* ) = self.fields;
                     #( #assignments )*
                     #name {
@@ -540,11 +552,49 @@ impl<'a> StructInfo<'a> {
     }
 }
 
+#[derive(Debug, Default, Clone)]
+pub struct BuildMethodSettings {
+    pub vis: Option<syn::Visibility>,
+    pub name: Option<syn::Expr>,
+}
+impl BuildMethodSettings {
+    fn apply_meta(&mut self, expr: syn::Expr) -> Result<(), Error> {
+        match expr {
+            syn::Expr::Assign(assign) => {
+                let name =
+                    expr_to_single_string(&assign.left).ok_or_else(|| Error::new_spanned(&assign.left, "Expected identifier"))?;
+                match name.as_str() {
+                    "vis" => {
+                        if let syn::Expr::Lit(expr_lit) = &*assign.right {
+                            if let syn::Lit::Str(ref s) = expr_lit.lit {
+                                self.vis = Some(syn::parse_str(&s.value()).expect("invalid visibility found"));
+                            }
+                        }
+                        if self.vis.is_none() {
+                            panic!("invalid visibility found")
+                        }
+                        Ok(())
+                    }
+                    "name" => {
+                        self.name = Some(*assign.right);
+                        Ok(())
+                    }
+                    _ => Err(Error::new_spanned(&assign, format!("Unknown parameter {:?}", name))),
+                }
+            }
+            _ => Err(Error::new_spanned(expr, "Expected (<...>=<...>)")),
+        }
+    }
+}
+
 #[derive(Debug, Default)]
 pub struct TypeBuilderAttr {
     /// Whether to show docs for the `TypeBuilder` type (rather than hiding them).
     pub doc: bool,
 
+    /// Customize build method, ex. visibility, name
+    pub build_method: BuildMethodSettings,
+
     /// Docs on the `Type::builder()` method.
     pub builder_method_doc: Option<syn::Expr>,
 
@@ -560,8 +610,8 @@ pub struct TypeBuilderAttr {
 }
 
 impl TypeBuilderAttr {
-    pub fn new(attrs: &[syn::Attribute]) -> Result<TypeBuilderAttr, Error> {
-        let mut result = TypeBuilderAttr::default();
+    pub fn new(attrs: &[syn::Attribute]) -> Result<Self, Error> {
+        let mut result = Self::default();
         for attr in attrs {
             if path_to_single_string(&attr.path).as_deref() != Some("builder") {
                 continue;
@@ -577,7 +627,7 @@ impl TypeBuilderAttr {
                     result.apply_meta(*body.expr)?;
                 }
                 syn::Expr::Tuple(body) => {
-                    for expr in body.elems.into_iter() {
+                    for expr in body.elems {
                         result.apply_meta(expr)?;
                     }
                 }
@@ -641,6 +691,12 @@ impl TypeBuilderAttr {
                         }
                         Ok(())
                     }
+                    "build_method" => {
+                        for arg in call.args {
+                            self.build_method.apply_meta(arg)?;
+                        }
+                        Ok(())
+                    }
                     _ => Err(Error::new_spanned(
                         &call.func,
                         format!("Illegal builder setting group name {}", subsetting_name),
